# There are no source releases for ocaml-cairo.  To get the source
# matching this you have to do:
#
# cvs -d:pserver:anonymous@cvs.cairographics.org:/cvs/cairo co -D 2008-03-01 cairo-ocaml
# tar zcf /tmp/ocaml-cairo-1.2.0.cvs20080301.tar.gz --exclude CVS cairo-ocaml
#
# Whether you'll get precisely the same tarball by this method is
# questionable.  If files get checked out in a different order then
# you might need to use 'diff -urN' instead of comparing MD5 hashes.

# Using git:
# $ git clone git://anongit.freedesktop.org/cairo-ocaml
# $ git archive --format=tar --prefix=cairo-ocaml/ master | gzip > ocaml-cairo-1.2.0.2.tar.gz
# 
# This 1.2.0.2 corresponds to a 28-06-2012 checkout.


Name:           ocaml-cairo
Version:        1.2.0.2
Release:        %mkrel 3

Summary:        OCaml library for accessing cairo graphics
Group:          Development/OCaml
License:        LGPLv2

URL:            http://cairographics.org/cairo-ocaml/
Source0:        ocaml-cairo-%{version}.tar.gz
Source1:        ocaml-cairo-META

Requires:       ocaml-lablgtk2
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-lablgtk2-devel
BuildRequires:  cairo-devel
BuildRequires:  automake
BuildRequires:  gtk2-devel
BuildRequires:  chrpath

%description
Cairo is a multi-platform library providing anti-aliased vector-based
rendering for multiple target backends. Paths consist of line segments
and cubic splines and can be rendered at any width with various join
and cap styles. All colors may be specified with optional translucence
(opacity/alpha) and combined using the extended Porter/Duff
compositing algebra as found in the X Render Extension.

Cairo exports a stateful rendering API similar in spirit to the path
construction, text, and painting operators of PostScript, (with the
significant addition of translucence in the imaging model). When
complete, the API is intended to support the complete imaging model of
PDF 1.4.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       cairo-devel
Requires:       ocaml-lablgtk2-devel

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n cairo-ocaml
aclocal -I support
autoconf
%configure2_5x
cp %{SOURCE1} META

%build
make
make doc
sed -i -e 's:@VERSION@:%{version}:g' META

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR $OCAMLFIND_DESTDIR/stublibs
ocamlfind install cairo src/{*.mli,*.cmi,*.cma,*.a,*.cmxa,*.cmx,dll*.so} META

#remove stripping to fix missing debug files?
#strip #{buildroot}#{_libdir}/ocaml/stublibs/dll*.so
chrpath --delete %{buildroot}%{_libdir}/ocaml/stublibs/dll*.so

%files
%doc COPYING
%{_libdir}/ocaml/cairo
%exclude %{_libdir}/ocaml/cairo/*.a
%exclude %{_libdir}/ocaml/cairo/*.cmxa
%exclude %{_libdir}/ocaml/cairo/*.cmx
%exclude %{_libdir}/ocaml/cairo/*.mli
%{_libdir}/ocaml/stublibs/*.so
%{_libdir}/ocaml/stublibs/*.so.owner

%files devel
%doc COPYING ChangeLog README doc/html
%{_libdir}/ocaml/cairo/*.a
%{_libdir}/ocaml/cairo/*.cmxa
%{_libdir}/ocaml/cairo/*.cmx
%{_libdir}/ocaml/cairo/*.mli





%changelog
* Mon Sep 26 2016 pterjan <pterjan> 1.2.0.2-3.mga6
+ Revision: 1056264
- Rebuild for fix in ocaml

* Tue Feb 16 2016 umeabot <umeabot> 1.2.0.2-2.mga6
+ Revision: 961782
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 eatdirt <eatdirt> 1.2.0.2-1.mga6
+ Revision: 886272
- Upgrade to latest git HEAD 1.2.0.2

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0.1-13.mga5
+ Revision: 742339
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0.1-12.mga5
+ Revision: 682997
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0.1-11.mga4
+ Revision: 523299
- Mageia 4 Mass Rebuild

* Sat Apr 06 2013 malo <malo> 1.2.0.1-10.mga3
+ Revision: 408604
- fix requires and buildrequires

* Sat Jan 12 2013 umeabot <umeabot> 1.2.0.1-9.mga3
+ Revision: 361181
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 blue_prawn <blue_prawn> 1.2.0.1-8.mga3
+ Revision: 302046
- rebuild for new ocaml 4.00

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.2.0.1-7.mga3
+ Revision: 300045
- new rpm group for ocaml

* Sun Dec 04 2011 malo <malo> 1.2.0.1-6.mga2
+ Revision: 176184
- adding missing Require ocaml-lablgtk2-devel
- spec clean-up
- adding missing Requires ocaml-lablgtk2

* Sun Nov 06 2011 malo <malo> 1.2.0.1-5.mga2
+ Revision: 164430
- using mkrel for release
- imported package ocaml-cairo


* Mon Sep 19 2011 Alexandre Lissy <alissy@mandriva.com> 1.2.0.1-5
+ Revision: 700302
- Changing BuildRequires against ocaml-lablgtk2 to -devel
- Updating version
- Release bump
- Using tarball from git, not cvs
  Updating BuildRequires against ocaml-lablgtk2 instead of ocaml-lablgtk2-devel because of pango.cmo needed

* Thu Apr 22 2010 Florent Monnier <blue_prawn@mandriva.org> 1.2.0.cvs20080301-4.1mdv2011.0
+ Revision: 537991
- just a rebuild to fix the "inconsistent assumptions over interface" problem

* Sun Jun 28 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.2.0.cvs20080301-4mdv2010.0
+ Revision: 390235
- rebuild

* Sat Feb 21 2009 Florent Monnier <blue_prawn@mandriva.org> 1.2.0.cvs20080301-3mdv2009.1
+ Revision: 343706
- incremented rel number
- added version in the META file

* Tue Feb 03 2009 Florent Monnier <blue_prawn@mandriva.org> 1.2.0.cvs20080301-2mdv2009.1
+ Revision: 337135
- The initial RPM release was made from the fedora rpm .spec file (revision 1.7) by Richard W.M. Jones
- import ocaml-cairo


* Tue Dec 16 2008 Florent Monnier <fmonnier@linux-nantes.org> 1.2.0.cvs20080301-1mdv
- Initial RPM release made from the redhat rpm .spec file (revision 1.7) by Richard W.M. Jones
